@@ -29,7 +29,7 @@ sub init {
     my $self = shift;
     $self->{complete} = new JMX::Jmx4Perl::J4psh::CompletionHandler($self);
     $self->{servers} = new JMX::Jmx4Perl::J4psh::ServerHandler($self);
-    $self->{shell} = new JMX::Jmx4Perl::J4psh::Shell(config => $self->config->{shell},args => $self->{args});;
+    $self->{shell} = new JMX::Jmx4Perl::J4psh::Shell(config => $self->config->{shell},args => $self->args);;
     my $no_color_prompt = $self->{shell}->readline ne "Term::ReadLine::Gnu";
     $self->{commands} = new JMX::Jmx4Perl::J4psh::CommandHandler($self,$self->{shell},
                                                                  no_color_prompt => $no_color_prompt,
@@ -49,6 +49,10 @@ sub config {
     return shift->{config};
 }
 
+sub args {
+    return shift->{args};
+}
+
 sub complete {
     return shift->{complete};
 }
@@ -132,7 +136,6 @@ sub _legacy_check {
     my $version = $resp->{agent};
     $version =~ s/^(\d+(\.\d+)).*$/$1/;
     if ($version < 1.0) {
-        print "L\n";
         $j4p->cfg('legacy-escape',1);
     }
 }
